From 1e707c63a9edb6120ee813a4138a68ad1d140116 Mon Sep 17 00:00:00 2001
From: Daniel Gustafsson <daniel@yesql.se>
Date: Wed, 30 Aug 2017 19:25:07 +0200
Subject: [PATCH] Remove to pre-8.2 coding convention for PG_MODULE_MAGIC

PG_MODULE_MAGIC has been around since 8.2, with 8.1 long since in
EOL, so remove the mention of #ifdef guards for compiling against
pre-8.2 sources from the documentation.

Also remove the last remaining #ifdef guards in the code.
---
 contrib/citext/citext.c     |  2 --
 doc/src/sgml/plhandler.sgml |  2 --
 doc/src/sgml/spi.sgml       |  2 --
 doc/src/sgml/xfunc.sgml     | 14 +-------------
 src/test/regress/regress.c  |  2 --
 5 files changed, 1 insertion(+), 21 deletions(-)

diff --git a/contrib/citext/citext.c b/contrib/citext/citext.c
index 04f604b15f..0ba47828ba 100644
--- a/contrib/citext/citext.c
+++ b/contrib/citext/citext.c
@@ -9,9 +9,7 @@
 #include "utils/formatting.h"
 #include "utils/varlena.h"
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 /*
  *		====================
diff --git a/doc/src/sgml/plhandler.sgml b/doc/src/sgml/plhandler.sgml
index 57a2a05ed2..2573e67743 100644
--- a/doc/src/sgml/plhandler.sgml
+++ b/doc/src/sgml/plhandler.sgml
@@ -108,9 +108,7 @@
 #include "catalog/pg_proc.h"
 #include "catalog/pg_type.h"
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 PG_FUNCTION_INFO_V1(plsample_call_handler);
 
diff --git a/doc/src/sgml/spi.sgml b/doc/src/sgml/spi.sgml
index 86be87c0fd..d04b5a2125 100644
--- a/doc/src/sgml/spi.sgml
+++ b/doc/src/sgml/spi.sgml
@@ -4352,9 +4352,7 @@ INSERT INTO a SELECT * FROM a;
 #include "executor/spi.h"
 #include "utils/builtins.h"
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 int64 execq(text *sql, int cnt);
 
diff --git a/doc/src/sgml/xfunc.sgml b/doc/src/sgml/xfunc.sgml
index cd6dd840ba..197e20022e 100644
--- a/doc/src/sgml/xfunc.sgml
+++ b/doc/src/sgml/xfunc.sgml
@@ -1757,22 +1757,14 @@ CREATE FUNCTION square_root(double precision) RETURNS double precision
     file contains a <quote>magic block</> with the appropriate contents.
     This allows the server to detect obvious incompatibilities, such as code
     compiled for a different major version of
-    <productname>PostgreSQL</productname>.  A magic block is required as of
-    <productname>PostgreSQL</productname> 8.2.  To include a magic block,
+    <productname>PostgreSQL</productname>. To include a magic block,
     write this in one (and only one) of the module source files, after having
     included the header <filename>fmgr.h</>:
 
 <programlisting>
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 </programlisting>
 
-    The <literal>#ifdef</> test can be omitted if the code doesn't
-    need to compile against pre-8.2 <productname>PostgreSQL</productname>
-    releases.
-   </para>
-
    <para>
     After it is used for the first time, a dynamically loaded object
     file is retained in memory.  Future calls in the same session to
@@ -2214,9 +2206,7 @@ PG_FUNCTION_INFO_V1(funcname);
 #include "fmgr.h"
 #include "utils/geo_decls.h"
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 /* by value */
 
@@ -2554,9 +2544,7 @@ SELECT name, c_overpaid(emp, 1500) AS overpaid
 #include "postgres.h"
 #include "executor/executor.h"  /* for GetAttributeByName() */
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 PG_FUNCTION_INFO_V1(c_overpaid);
 
diff --git a/src/test/regress/regress.c b/src/test/regress/regress.c
index 3d33b36e66..734947cc98 100644
--- a/src/test/regress/regress.c
+++ b/src/test/regress/regress.c
@@ -46,9 +46,7 @@
 extern PATH *poly2path(POLYGON *poly);
 extern void regress_lseg_construct(LSEG *lseg, Point *pt1, Point *pt2);
 
-#ifdef PG_MODULE_MAGIC
 PG_MODULE_MAGIC;
-#endif
 
 
 /*
-- 
2.14.1.145.gb3622a4ee

